@@ -10,12 +10,29 @@ DER_ENABLED_INTEGRATIONS = (
 
 DER_INCLUDE_REQUEST_TAGS = True  # Include end user information as span tags
 
+DER_HEADERS_IP_ADDRESS = "REMOTE_ADDR"
+
+DER_HEADER_TAGS = None
+
 #
 # DataDog
 
 
+#
+# Sentry
+
+DER_SENTRY_DSN = None
+DER_SENTRY_INTEGRATIONS = []
+DER_SENTRY_TRACES_SAMPLE_RATE = 0.0
+DER_SENTRY_ENV = "local"
+DER_SENTRY_REQUEST_BODIES = "always"
+DER_SENTRY_RELEASE = "0"
+DER_SENTRY_DEBUG = None
+
+
 #
 # Logging
+
 DER_LOGGING_LEVEL = logging.ERROR
 
 # DataDog Logging
